==> crnk-core-0.9.20170524133411-sources.jar: io/crnk/core/engine/document/ResourceIdentifier.java <==
package io.crnk.core.engine.document;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

public class ResourceIdentifier implements Comparable<ResourceIdentifier> {

	private String id;

	private String type;

	public ResourceIdentifier() {
	}

	public ResourceIdentifier(String id, String type) {
		this.id = id;
		this.type = type;
	}

	public static Object fromData(Object data) {
		if (data == null) {
			return null;
		}
		if (data instanceof Iterable) {
			List<ResourceIdentifier> result = new ArrayList<>();
			for (ResourceIdentifier id : (Iterable<ResourceIdentifier>) data) {
				result.add(id.clone());
			}
			return result;
		} else {
			ResourceIdentifier id = (ResourceIdentifier) data;
			return id.clone();
		}
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	@Override
	public ResourceIdentifier clone() {
		return new ResourceIdentifier(id, type);
	}

	@Override
	public int hashCode() {
		return Objects.hash(id, type);
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null || obj.getClass() != this.getClass())
			return false;
		ResourceIdentifier other = (ResourceIdentifier) obj;
		return Objects.equals(id, other.id) && Objects.equals(type, other.type);
	}

	@Override
	public int compareTo(ResourceIdentifier o) {
		int d = type.compareTo(o.type);
		if (d != 0) {
			return d;
		}
		return id.compareTo(o.id);
	}

	@Override
	public String toString() {
		return "ResourceIdentifier{" +
				"id='" + id + '\'' +
				", type='" + type + '\'' +
				'}';
	}
}

==> crnk-core-2.5.20180215232038-sources.jar: io/crnk/core/engine/document/ResourceIdentifier.java <==
package io.crnk.core.engine.document;

import io.crnk.core.engine.information.resource.ResourceInformation;
import java.util.Objects;

import io.crnk.core.engine.internal.utils.PreconditionUtil;

public class ResourceIdentifier implements Comparable<ResourceIdentifier> {

	protected String id;

	protected String type;

	public ResourceIdentifier() {
	}

	public ResourceIdentifier(String id, String type) {
		PreconditionUtil.assertNotNull("id cannot be null", id);
		PreconditionUtil.assertNotNull("type cannot be null", type);
		PreconditionUtil.assertFalse("cannot pass ResourceIdentifier as id", id.startsWith("ResourceIdentifier{id="));
		this.id = id;
		this.type = type;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	@Override
	public int hashCode() {
		return Objects.hash(id, type);
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null || obj.getClass() != this.getClass()) {
			return false;
		}
		ResourceIdentifier other = (ResourceIdentifier) obj;
		return Objects.equals(id, other.id) && Objects.equals(type, other.type);
	}

	@Override
	public int compareTo(ResourceIdentifier o) {
		int d = type.compareTo(o.type);
		if (d != 0) {
			return d;
		}
		return id.compareTo(o.id);
	}

	@Override
	public String toString() {
		return "ResourceIdentifier{" +
				"id='" + id + '\'' +
				", type='" + type + '\'' +
				'}';
	}
}
